from pdfminer.pdfinterp import PDFResourceManager, PDFPageInterpreter
from pdfminer.converter import TextConverter
from pdfminer.layout import LAParams
from pdfminer.pdfpage import PDFPage
from io import StringIO
import re


def pdf_to_paper(fp):
    rsrcmgr = PDFResourceManager()
    retstr = StringIO()
    codec = "utf-8"
    laparams = LAParams()
    device = TextConverter(rsrcmgr, retstr, codec=codec, laparams=laparams)
    interpreter = PDFPageInterpreter(rsrcmgr, device)
    password = ""
    maxpages = 0
    caching = True
    pagenos = set()

    for page in PDFPage.get_pages(
        fp,
        pagenos,
        maxpages=maxpages,
        password=password,
        caching=caching,
        check_extractable=True,
    ):
        interpreter.process_page(page)

    text = retstr.getvalue()
    abstract_loc = text.find("Abstract")
    abstract = text[abstract_loc:]
    end = abstract.find("\n\n", 200)
    abstract = abstract[len("Abstract:") : end]

    year = re.findall(r"\d\d\d\d|$", text)[0]

    journal = re.findall(r"[A-Z][A-Z][A-Z][A-Z]+", text)[0]

    url = re.findall(
        r"(http\:\/\/|https\:\/\/)?([a-z0-9][a-z0-9\-]*\.)+[a-z0-9][a-z0-9\-]*|$", text
    )[0]
    return {"abstract": abstract.strip(), "year": year, "journal": journal, "url": url}

