import requests
from bs4 import BeautifulSoup
import re
import pandas as pd
from core import Paper, format_name, format_title


import requests_cache

# optional but prevents from redownloading all the pages during developement
requests_cache.install_cache("html_cache")

journals = [
    {"name": "ISEDJ", "base_url": "http://isedj.org/"},
    {"name": "JISE", "base_url": "http://jise.org/"},
]


def get_paper(url):
    raw_html = requests.get(url).content
    soup = BeautifulSoup(raw_html, features="lxml")
    if soup.find("meta", attrs={"name": "citation_title"}) is not None:
        return get_paper_v1(soup, url)
    else:
        return get_paper_v0(soup, url)


def get_paper_v1(soup, url):
    title = soup.find("meta", attrs={"name": "citation_title"}).get("content")
    abstract = soup.find(string="Abstract: ").parent.next_sibling
    date = soup.find("meta", attrs={"name": "citation_date"}).get("content")[
        :4
    ]  # just year for now
    authors = [
        format_name(meta.get("content"))
        for meta in soup.find_all("meta", attrs={"name": "citation_author"})
    ]
    keywords = soup.find("meta", attrs={"name": "keywords"}).get("content").split(", ")
    return Paper(title, "", abstract, date, authors, keywords, url)


def get_paper_v0(soup, url):
    title = soup.find_all("h2")[-1].text
    abstract = soup.find(string="Abstract:").parent.next_sibling
    date = soup.find_all("h3")[-1].text[-4:]  # just year for now
    authors = get_authors_v0(soup)
    keywords = soup.find(string="Keywords:").parent.next_sibling.split(", ")
    return Paper(title, "", abstract, date, authors, keywords, url)


def get_authors_v0(soup):
    authors = []
    for p in soup.find_all("p"):
        for b in p.find_all("b"):
            if b.text == "Abstract:":
                return authors
        else:
            authors.append(format_name(b.text))
    return []


for journal in journals:
    base_url = journal["base_url"]
    archive_url = f"{base_url}archives.html"

    archives = requests.get(archive_url).content
    soup = BeautifulSoup(archives, features="lxml")

    heading = soup.find(string=f"{journal['name']} Archives").parent

    volume_urls = [
        f"{base_url}{a.get('href')}" for a in heading.next_sibling.parent.find_all("a")
    ]
    urls = []

    for url in volume_urls:
        volume = requests.get(url).content
        soup = BeautifulSoup(volume, features="lxml")
        print(f"url:{url}")
        table_contents_header = soup.find_all(string=re.compile("Contents"))[-1].parent
        paper_urls = [
            f"{url.replace('index.html', '')}{a.get('href')}"
            for a in table_contents_header.parent.find_all("a")
        ]
        urls.extend(paper_urls)

    papers = []
    fails = []

    for url in urls:
        if url.endswith(".html"):
            print(url)
            try:
                paper = get_paper(url)
                paper = paper._replace(journal=journal["name"])
                papers.append(paper)
            except Exception as e:
                fails.append((url, e))

    df = pd.DataFrame.from_records(papers, columns=Paper._fields)
    df.to_pickle(f"{journal['name'].lower()}.pickle")

    print(fails)

